Package: GeoTcgaData
Type: Package
Title: Processing Various Types of Data on GEO and TCGA
Version: 2.12.0
Authors@R: person(given = "Erqiang", family = "Hu", email = "13766876214@163.com", role  = c("aut", "cre"), comment = c(ORCID = "0000-0002-1798-7513"))
Description: Gene Expression Omnibus(GEO) and The Cancer Genome Atlas
        (TCGA) provide us with a wealth of data, such as RNA-seq, DNA
        Methylation, SNP and Copy number variation data. It's easy to
        download data from TCGA using the gdc tool, but processing
        these data into a format suitable for bioinformatics analysis
        requires more work. This R package was developed to handle
        these data.
Depends: R (>= 4.2.0)
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown, DESeq2, S4Vectors, ChAMP, impute, tidyr,
        clusterProfiler, org.Hs.eg.db, edgeR, limma, quantreg, minfi,
        IlluminaHumanMethylation450kanno.ilmn12.hg19, dearseq, NOISeq,
        testthat (>= 3.0.0), CATT, TCGAbiolinks, enrichplot, GEOquery,
        BiocGenerics
VignetteBuilder: knitr
Imports: utils, data.table, plyr, cqn, topconfects, stats,
        SummarizedExperiment, methods
Language: en-US
URL: https://github.com/YuLab-SMU/GeoTcgaData
BugReports: https://github.com/YuLab-SMU/GeoTcgaData/issues
biocViews: GeneExpression, DifferentialExpression, RNASeq,
        CopyNumberVariation, Microarray, Software, DNAMethylation,
        DifferentialMethylation, SNP, ATACSeq, MethylationArray
Config/testthat/edition: 3
Config/pak/sysreqs: zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 13:00:16 UTC
RemoteUrl: https://github.com/bioc/GeoTcgaData
RemoteRef: RELEASE_3_23
RemoteSha: 4738d3e067f9f1ffd220e5ae50a931b31aa382e7
NeedsCompilation: no
Packaged: 2026-04-29 22:32:28 UTC; root
Author: Erqiang Hu [aut, cre] (ORCID: <https://orcid.org/0000-0002-1798-7513>)
Maintainer: Erqiang Hu <13766876214@163.com>
Built: R 4.6.0; ; 2026-04-30 00:25:19 UTC; unix
