# Generated by roxygen2: do not edit by hand

export(Merge_methy_tcga)
export(SNP_QC)
export(array_preprocess)
export(cal_mean_module)
export(cluster_array)
export(combine_pvalue)
export(countToFpkm)
export(countToTpm)
export(differential_CNV)
export(differential_RNA)
export(differential_SNP)
export(differential_SNP_GEO)
export(differential_SNP_tcga)
export(differential_array)
export(differential_limma)
export(differential_methy)
export(fpkmToTpm)
export(gene_ave)
export(get_geo_array)
export(id_conversion_TCGA)
export(prepare_chi)
export(repAssign)
export(repRemove)
import(cqn)
import(methods)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(plyr,rename)
importFrom(stats,as.dist)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,hclust)
importFrom(stats,na.fail)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(utils,methods)
